Change History for aiodjango
============================


v0.1 (2015-12-20)
-----------------

Initial packaged release.

- Basic API for detecting async views and wrapping in ``aiohttp`` application. No dynamic route support.
- Runserver integration for local development.
